# sketch-clip
## How to run
```
pip install -r requirements.txt
python sketch_clip.py
```

## Download model
```
wget https://openaipublic.azureedge.net/clip/models/5806e77cd80f8b59890b7e101eabd078d9fb84e6937f9e85e4ecb61988df416f/ViT-B-16.pt
```

